@@ -1,4 +1,6 @@
-"""Python 2 Verilog"""
+"""
+Python 2 Verilog
+"""
 
 # flake8: noqa
 from . import frontend
